"""
Interface to the Crassus Lambda function. This module notifies Crassus
about updates to a CFN stack so Crassus will trigger the update process.
"""
# -*- coding: utf-8 -*-
from boto3 import client
import json
from gaius.compat import OrderedDict

CRASSUS_MESSAGE_VERSION = 1


def notify_crassus(stack_name, parameters, topic_arn, region):
    """ Sends an update notification to Crassus """
    message = transform_to_message_format(stack_name, parameters, region)
    sns_client = client('sns', region_name=region)
    json_str = sns_client.publish(
        TopicArn=topic_arn,
        Message=message
    )
    return json_str


def transform_to_message_format(stack_name, parameters, region):
    message = {}
    message['version'] = CRASSUS_MESSAGE_VERSION
    message['stackName'] = stack_name
    message['region'] = region

    parameter_list = [x for x in parameters.split(',')]
    parameter_dict = dict([y.split('=') for y in parameter_list])
    message['parameters'] = parameter_dict

    return json.dumps(OrderedDict(sorted(message.items())))



"""
Command line client for deploying CFN stacks via crassus
Usage:
    gaius --stack STACK --parameters PARAMETERS --topic-arn ARN [--region REGION]

Options:
  -h --help                Show this.
  --stack STACK            Stack Name.
  --parameters PARAMETERS  Parameters in format key=value[,key=value].
  --topic-arn ARN          The ARN of the notify topic.
  --region REGION          The region to deploy in. [default: eu-west-1]
"""

from gaius import crassus
from docopt import docopt


def send_message():
    arguments = docopt(__doc__)
    stack_name = arguments['--stack']
    parameters = arguments['--parameters']
    topic_arn = arguments['--topic-arn']
    region = arguments['--region']

    print crassus.notify_crassus(stack_name, parameters, topic_arn, region)



""" Compatability module for different Python versions. """

try:
    from ordereddict import OrderedDict  # NOQA
except ImportError:  # pragma: no cover
    from collections import OrderedDict  # NOQA
